"""Autogenerated file: DO NOT EDIT!"""
import typing  # noqa: F401
from dazzler.system import Component, Aspect, UNDEFINED  # noqa: F401


class Drawer(Component):
    """
    Draw content from the sides of the screen.
    """
    _aspect_keys = []
    _children = []
    children = Aspect(children=True)
    opened = Aspect()
    style = Aspect()
    class_name = Aspect()
    side = Aspect(default="'top'", docstring="Side which open. (Possible values: 'top', 'left', 'right', 'bottom') (default="'top'")")  # noqa: E501

    def __init__(
            self,
            children: typing.Optional[typing.Union[str, int, float, Component, typing.List[typing.Union[str, int, float, Component]]]] = UNDEFINED,  # noqa: E501
            opened: typing.Optional[bool] = UNDEFINED,
            style: typing.Optional[typing.Dict] = UNDEFINED,
            class_name: typing.Optional[str] = UNDEFINED,
            side: typing.Optional[typing.Any] = "'top'",
            identity: str = None
    ):
        """
        :param children:
        :param opened:
        :param style:
        :param class_name:
        :param side: Side which open. (Possible values: 'top', 'left',
            'right', 'bottom') (default="'top'")
        """
        Component.__init__(self, locals(), identity)
