"""Autogenerated file: DO NOT EDIT!"""
import typing  # noqa: F401
from dazzler.system import Component, Aspect, UNDEFINED  # noqa: F401


class DataList(Component):
    """
    A html datalist (select with autocomplete).
    """
    _aspect_keys = []
    _children = []
    options = Aspect(required=True, docstring="Options of the datalist.")
    id = Aspect(docstring="Unique id for the component.")
    class_name = Aspect(docstring="CSS class.")
    value = Aspect(docstring="Value of the text input.")
    data_value = Aspect(docstring="The value of the selected option if found.")
    title = Aspect(docstring="Tooltip.")

    def __init__(
            self,
            options: typing.List[typing.Dict[str, typing.Union[typing.Any, str]]],  # noqa: E501
            id: typing.Optional[str] = UNDEFINED,
            class_name: typing.Optional[str] = UNDEFINED,
            value: typing.Optional[str] = UNDEFINED,
            data_value: typing.Optional[typing.Any] = UNDEFINED,
            title: typing.Optional[str] = UNDEFINED,
            identity: str = None
    ):
        """
        :param options: Options of the datalist.
        :param id: Unique id for the component.
        :param class_name: CSS class.
        :param value: Value of the text input.
        :param data_value: The value of the selected option if found.
        :param title: Tooltip.
        """
        Component.__init__(self, locals(), identity)
