"""Autogenerated file: DO NOT EDIT!"""
import typing  # noqa: F401
from dazzler.system import Component, Aspect, UNDEFINED  # noqa: F401


class Container(Component):
    """
    Virtual div

    :CSS:

        ``dazzler-core-container``.
        - ``scroll``
        - ``flex``
        - ``row``
        - ``column``
        - ``btn``
    """
    _aspect_keys = []
    _children = []
    children = Aspect(children=True)
    id = Aspect()
    class_name = Aspect()
    style = Aspect()
    title = Aspect()
    draggable = Aspect()
    clicks = Aspect(default=0, docstring="Number of times the container was clicked. (default=0)")  # noqa: E501

    def __init__(
            self,
            children: typing.Optional[typing.Union[str, int, float, Component, typing.List[typing.Union[str, int, float, Component]]]] = UNDEFINED,  # noqa: E501
            id: typing.Optional[str] = UNDEFINED,
            class_name: typing.Optional[str] = UNDEFINED,
            style: typing.Optional[typing.Dict] = UNDEFINED,
            title: typing.Optional[str] = UNDEFINED,
            draggable: typing.Optional[bool] = UNDEFINED,
            clicks: typing.Optional[typing.Union[float, int]] = 0,
            identity: str = None
    ):
        """
        :param children:
        :param id:
        :param class_name:
        :param style:
        :param title:
        :param draggable:
        :param clicks: Number of times the container was clicked.
            (default=0)
        """
        Component.__init__(self, locals(), identity)
