.dazzler-renderer .primary {
  background-color: #5294e2; }

.dazzler-renderer .primary-light {
  background-color: #52a3f1; }

.dazzler-renderer .danger {
  background-color: #D9534F; }

.dazzler-renderer .danger-light {
  background-color: #DE6C69; }

.dazzler-renderer .warning {
  background-color: #F0AD4E; }

.dazzler-renderer .warning-light {
  background-color: #F2B968; }

.dazzler-renderer .success {
  background-color: #5CB85C; }

.dazzler-renderer .success-light {
  background-color: #74c274; }

.dazzler-spin {
  width: 3rem;
  height: 3rem;
  border: 4px solid #c9c9ce;
  border-top-color: #5294e2;
  border-radius: 50%;
  -webkit-transition-property: -webkit-transform;
  -webkit-transition-duration: 1.2s;
  -webkit-animation-name: rotate;
  -webkit-animation-iteration-count: infinite;
  -webkit-animation-timing-function: linear;
  -moz-transition-property: -moz-transform;
  -moz-animation-name: rotate;
  -moz-animation-duration: 1.2s;
  -moz-animation-iteration-count: infinite;
  -moz-animation-timing-function: linear;
  transition-property: transform;
  animation-name: rotate;
  animation-duration: 1.2s;
  animation-iteration-count: infinite;
  animation-timing-function: linear; }

@-webkit-keyframes rotate {
  from {
    -webkit-transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg); } }

@-moz-keyframes rotate {
  from {
    -moz-transform: rotate(0deg); }
  to {
    -moz-transform: rotate(360deg); } }

@keyframes rotate {
  from {
    transform: rotate(0deg); }
  to {
    transform: rotate(360deg); } }

.dazzler-renderer {
  font-family: Lato, 'Helvetica Neue', Arial, Helvetica, sans-serif; }

.dazzler-loading {
  text-align: center; }

.dazzler-loading-container {
  margin-top: 1rem; }
  .dazzler-loading-container .dazzler-spin {
    margin: 0 auto; }
    .dazzler-loading-container .dazzler-spin.reload {
      border-top-color: #F0AD4E; }
  .dazzler-loading-container .dazzler-loading {
    margin-top: 0.5rem; }


/*# sourceMappingURL=dazzler_commons_6ee7514ee44449b3f910.js.map*/