"""Autogenerated file: DO NOT EDIT!"""
import typing  # noqa: F401
from dazzler.system import Component, Aspect, UNDEFINED  # noqa: F401


class TimePicker(Component):
    """
    Time input with fallback for ie and safari.

    :CSS:

        ``dazzler-calendar-time-picker``
        - ``time-input``
        - ``fallback-timepicker``
        - ``time-range``
        - ``time-value``
    """
    _aspect_keys = []
    _children = []
    value = Aspect(default='00:00', docstring="Time value formatted as HH:MM (default='00:00')")  # noqa: E501
    fallback_mode = Aspect(docstring="Use a custom picker instead of browser dependant.Automatically set when no time input support detected.")  # noqa: E501
    mode = Aspect(default="'24h'", docstring="What to display when in fallback mode. (Possible values: '24h', 'AM/PM') (default="'24h'")")  # noqa: E501

    def __init__(
            self,
            value: typing.Optional[str] = '00:00',
            fallback_mode: typing.Optional[bool] = UNDEFINED,
            mode: typing.Optional[typing.Any] = "'24h'",
            identity: str = None
    ):
        """
        :param value: Time value formatted as HH:MM (default='00:00')
        :param fallback_mode: Use a custom picker instead of browser
            dependant. Automatically set when no time input support detected.
        :param mode: What to display when in fallback mode. (Possible
            values: '24h', 'AM/PM') (default="'24h'")
        """
        Component.__init__(self, locals(), identity)
