"""Autogenerated file: DO NOT EDIT!"""
import typing  # noqa: F401
from dazzler.system import Component, Aspect, UNDEFINED  # noqa: F401


class Grid(Component):
    """
    Render a list in a grid with a number of ``columns``.

    :CSS:

        ``dazzler-core-grid``
        - ``grid-row``
        - ``grid-cell``

    :Example:

    .. code-block:: python3

        from dazzler.components import core

        grid = core.Grid([1, 2, 3, 4], 2)
    """
    _aspect_keys = []
    _children = []
    children = Aspect(required=True, children=True, docstring="Children to render in a grid.")  # noqa: E501
    columns = Aspect(required=True, docstring="Number of columns")

    def __init__(
            self,
            children: typing.List[typing.Union[str, int, float, Component, typing.List[typing.Union[str, int, float, Component]]]],  # noqa: E501
            columns: typing.Union[float, int],
            identity: str = None
    ):
        """
        :param children: Children to render in a grid.
        :param columns: Number of columns
        """
        Component.__init__(self, locals(), identity)
