"""Autogenerated file: DO NOT EDIT!"""
import typing  # noqa: F401
from dazzler.system import Component, Aspect, UNDEFINED  # noqa: F401


class Spinner(Component):
    """
    Simple html/css spinner.
    """
    _aspect_keys = []
    _children = []
    class_name = Aspect()
    style = Aspect()

    def __init__(
            self,
            class_name: typing.Optional[str] = UNDEFINED,
            style: typing.Optional[typing.Dict] = UNDEFINED,
            identity: str = None
    ):
        """
        :param class_name:
        :param style:
        """
        Component.__init__(self, locals(), identity)
