"""Autogenerated file: DO NOT EDIT!"""
import typing  # noqa: F401
from dazzler.system import Component, Aspect, UNDEFINED  # noqa: F401


class Sticky(Component):
    """
    A shorthand component for a sticky div.
    """
    _aspect_keys = []
    _children = []
    children = Aspect(children=True)
    top = Aspect()
    left = Aspect()
    right = Aspect()
    bottom = Aspect()
    class_name = Aspect()
    style = Aspect()

    def __init__(
            self,
            children: typing.Optional[typing.Union[str, int, float, Component, typing.List[typing.Union[str, int, float, Component]]]] = UNDEFINED,  # noqa: E501
            top: typing.Optional[str] = UNDEFINED,
            left: typing.Optional[str] = UNDEFINED,
            right: typing.Optional[str] = UNDEFINED,
            bottom: typing.Optional[str] = UNDEFINED,
            class_name: typing.Optional[str] = UNDEFINED,
            style: typing.Optional[typing.Dict] = UNDEFINED,
            identity: str = None
    ):
        """
        :param children:
        :param top:
        :param left:
        :param right:
        :param bottom:
        :param class_name:
        :param style:
        """
        Component.__init__(self, locals(), identity)
