"""Autogenerated file: DO NOT EDIT!"""
import typing  # noqa: F401
from dazzler.system import Component, Aspect, UNDEFINED  # noqa: F401


class Store(Component):
    """
    Store data in the browser memory. Data last until the page is refreshed.
    """
    _aspect_keys = []
    _children = []
    data = Aspect(docstring="Stored data.")

    def __init__(
            self,
            data: typing.Optional[typing.Any] = UNDEFINED,
            identity: str = None
    ):
        """
        :param data: Stored data.
        """
        Component.__init__(self, locals(), identity)
