(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory(require("react"));
	else if(typeof define === 'function' && define.amd)
		define(["react"], factory);
	else if(typeof exports === 'object')
		exports["dazzler_test"] = factory(require("react"));
	else
		root["dazzler_test"] = factory(root["React"]);
})(window, function(__WEBPACK_EXTERNAL_MODULE_react__) {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// install a JSONP callback for chunk loading
/******/ 	function webpackJsonpCallback(data) {
/******/ 		var chunkIds = data[0];
/******/ 		var moreModules = data[1];
/******/ 		var executeModules = data[2];
/******/
/******/ 		// add "moreModules" to the modules object,
/******/ 		// then flag all "chunkIds" as loaded and fire callback
/******/ 		var moduleId, chunkId, i = 0, resolves = [];
/******/ 		for(;i < chunkIds.length; i++) {
/******/ 			chunkId = chunkIds[i];
/******/ 			if(installedChunks[chunkId]) {
/******/ 				resolves.push(installedChunks[chunkId][0]);
/******/ 			}
/******/ 			installedChunks[chunkId] = 0;
/******/ 		}
/******/ 		for(moduleId in moreModules) {
/******/ 			if(Object.prototype.hasOwnProperty.call(moreModules, moduleId)) {
/******/ 				modules[moduleId] = moreModules[moduleId];
/******/ 			}
/******/ 		}
/******/ 		if(parentJsonpFunction) parentJsonpFunction(data);
/******/
/******/ 		while(resolves.length) {
/******/ 			resolves.shift()();
/******/ 		}
/******/
/******/ 		// add entry modules from loaded chunk to deferred list
/******/ 		deferredModules.push.apply(deferredModules, executeModules || []);
/******/
/******/ 		// run deferred modules when all chunks ready
/******/ 		return checkDeferredModules();
/******/ 	};
/******/ 	function checkDeferredModules() {
/******/ 		var result;
/******/ 		for(var i = 0; i < deferredModules.length; i++) {
/******/ 			var deferredModule = deferredModules[i];
/******/ 			var fulfilled = true;
/******/ 			for(var j = 1; j < deferredModule.length; j++) {
/******/ 				var depId = deferredModule[j];
/******/ 				if(installedChunks[depId] !== 0) fulfilled = false;
/******/ 			}
/******/ 			if(fulfilled) {
/******/ 				deferredModules.splice(i--, 1);
/******/ 				result = __webpack_require__(__webpack_require__.s = deferredModule[0]);
/******/ 			}
/******/ 		}
/******/
/******/ 		return result;
/******/ 	}
/******/
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// object to store loaded and loading chunks
/******/ 	// undefined = chunk not loaded, null = chunk preloaded/prefetched
/******/ 	// Promise = chunk loading, 0 = chunk loaded
/******/ 	var installedChunks = {
/******/ 		"test": 0
/******/ 	};
/******/
/******/ 	var deferredModules = [];
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, { enumerable: true, get: getter });
/******/ 		}
/******/ 	};
/******/
/******/ 	// define __esModule on exports
/******/ 	__webpack_require__.r = function(exports) {
/******/ 		if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 			Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 		}
/******/ 		Object.defineProperty(exports, '__esModule', { value: true });
/******/ 	};
/******/
/******/ 	// create a fake namespace object
/******/ 	// mode & 1: value is a module id, require it
/******/ 	// mode & 2: merge all properties of value into the ns
/******/ 	// mode & 4: return value when already ns object
/******/ 	// mode & 8|1: behave like require
/******/ 	__webpack_require__.t = function(value, mode) {
/******/ 		if(mode & 1) value = __webpack_require__(value);
/******/ 		if(mode & 8) return value;
/******/ 		if((mode & 4) && typeof value === 'object' && value && value.__esModule) return value;
/******/ 		var ns = Object.create(null);
/******/ 		__webpack_require__.r(ns);
/******/ 		Object.defineProperty(ns, 'default', { enumerable: true, value: value });
/******/ 		if(mode & 2 && typeof value != 'string') for(var key in value) __webpack_require__.d(ns, key, function(key) { return value[key]; }.bind(null, key));
/******/ 		return ns;
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/ 	var jsonpArray = window["webpackJsonpdazzler_name_"] = window["webpackJsonpdazzler_name_"] || [];
/******/ 	var oldJsonpFunction = jsonpArray.push.bind(jsonpArray);
/******/ 	jsonpArray.push = webpackJsonpCallback;
/******/ 	jsonpArray = jsonpArray.slice();
/******/ 	for(var i = 0; i < jsonpArray.length; i++) webpackJsonpCallback(jsonpArray[i]);
/******/ 	var parentJsonpFunction = oldJsonpFunction;
/******/
/******/
/******/ 	// add entry module to deferred list
/******/ 	deferredModules.push([2,"commons"]);
/******/ 	// run deferred modules when ready
/******/ 	return checkDeferredModules();
/******/ })
/************************************************************************/
/******/ ({

/***/ "./src/internal/test_components/components/ComponentAsAspect.jsx":
/*!***********************************************************************!*\
  !*** ./src/internal/test_components/components/ComponentAsAspect.jsx ***!
  \***********************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return ComponentAsAspect; });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "./node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }




var ComponentAsAspect =
/*#__PURE__*/
function (_React$Component) {
  _inherits(ComponentAsAspect, _React$Component);

  function ComponentAsAspect() {
    _classCallCheck(this, ComponentAsAspect);

    return _possibleConstructorReturn(this, _getPrototypeOf(ComponentAsAspect).apply(this, arguments));
  }

  _createClass(ComponentAsAspect, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          identity = _this$props.identity,
          single = _this$props.single,
          array = _this$props.array,
          shape = _this$props.shape,
          list_of_dict = _this$props.list_of_dict;
      return react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        id: identity
      }, react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "single"
      }, single), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "array"
      }, array.map(function (e, i) {
        return react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
          key: i
        }, e);
      })), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "shape"
      }, shape.shaped), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "list_of_dict"
      }, list_of_dict.map(function (e) {
        return react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
          key: e.value
        }, e.label);
      })));
    }
  }]);

  return ComponentAsAspect;
}(react__WEBPACK_IMPORTED_MODULE_0___default.a.Component);


ComponentAsAspect.defaultProps = {};
ComponentAsAspect.propTypes = {
  single: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.element,
  array: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.arrayOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.element),
  shape: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    shaped: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.element
  }),
  list_of_dict: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.arrayOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    label: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,
    value: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.any
  })),

  /**
   *  Unique id for this component
   */
  identity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Update aspects on the backend.
   */
  updateAspects: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};

/***/ }),

/***/ "./src/internal/test_components/components/DefaultProps.jsx":
/*!******************************************************************!*\
  !*** ./src/internal/test_components/components/DefaultProps.jsx ***!
  \******************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return DefaultProps; });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "./node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }




var DefaultProps =
/*#__PURE__*/
function (_Component) {
  _inherits(DefaultProps, _Component);

  function DefaultProps() {
    _classCallCheck(this, DefaultProps);

    return _possibleConstructorReturn(this, _getPrototypeOf(DefaultProps).apply(this, arguments));
  }

  _createClass(DefaultProps, [{
    key: "render",
    value: function render() {
      var id = this.props.id;
      return react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        id: id
      }, Object.entries(this.props).map(function (k, v) {
        return react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
          id: "".concat(id, "-").concat(k),
          key: "".concat(id, "-").concat(k)
        }, k, ": ", JSON.stringify(v));
      }));
    }
  }]);

  return DefaultProps;
}(react__WEBPACK_IMPORTED_MODULE_0__["Component"]);


DefaultProps.defaultProps = {
  string_default: 'Default string',
  string_default_empty: '',
  number_default: 0.2666,
  number_default_empty: 0,
  array_default: [1, 2, 3],
  array_default_empty: [],
  object_default: {
    foo: 'bar'
  },
  object_default_empty: {}
};
DefaultProps.propTypes = {
  id: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,
  string_default: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,
  string_default_empty: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,
  number_default: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,
  number_default_empty: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,
  array_default: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.array,
  array_default_empty: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.array,
  object_default: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.object,
  object_default_empty: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.object
};

/***/ }),

/***/ "./src/internal/test_components/components/TestComponent.jsx":
/*!*******************************************************************!*\
  !*** ./src/internal/test_components/components/TestComponent.jsx ***!
  \*******************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return TestComponent; });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "./node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }




/**
 * Test component with all supported props by dazzler.
 * Each prop are rendered with a selector for easy access.
 */

var TestComponent =
/*#__PURE__*/
function (_Component) {
  _inherits(TestComponent, _Component);

  function TestComponent() {
    _classCallCheck(this, TestComponent);

    return _possibleConstructorReturn(this, _getPrototypeOf(TestComponent).apply(this, arguments));
  }

  _createClass(TestComponent, [{
    key: "render",
    value: function render() {
      return react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        id: this.props.id
      }, react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "array"
      }, this.props.array_prop && JSON.stringify(this.props.array_prop)), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "bool"
      }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["isNil"])(this.props.bool_prop) ? '' : this.props.bool_prop ? 'True' : 'False'), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "number"
      }, this.props.number_prop), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "object"
      }, this.props.object_prop && JSON.stringify(this.props.object_prop)), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "string"
      }, this.props.string_prop), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "symbol"
      }, this.props.symbol_prop), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "enum"
      }, this.props.enum_prop), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "union"
      }, this.props.union_prop), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "array_of"
      }, this.props.array_of_prop && JSON.stringify(this.props.array_of_prop)), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "object_of"
      }, this.props.object_of_prop && JSON.stringify(this.props.object_of_prop)), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "shape"
      }, this.props.shape_prop && JSON.stringify(this.props.shape_prop)), react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("div", {
        className: "required_string"
      }, this.props.required_string));
    }
  }]);

  return TestComponent;
}(react__WEBPACK_IMPORTED_MODULE_0__["Component"]);


TestComponent.defaultProps = {
  string_with_default: 'Foo'
};
TestComponent.propTypes = {
  /**
   * The ID used to identify this component in the DOM.
   * Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.
   */
  id: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Array props with
   */
  array_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.array,
  bool_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,
  func_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func,
  number_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,
  object_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.object,
  string_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,
  symbol_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.symbol,
  any_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.any,
  string_with_default: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,
  enum_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(['News', 'Photos']),
  // An object that could be one of many types
  union_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),
  // An array of a certain type
  array_of_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.arrayOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number),
  // An object with property values of a certain type
  object_of_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number),
  // An object taking on a particular shape
  shape_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    color: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,
    fontSize: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number
  }),
  required_string: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string.isRequired,
  // These don't work good.
  nested_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    string_prop: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,
    nested_shape: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
      nested_array: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.arrayOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
        nested_array_string: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,
        nested_array_shape: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
          prop1: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,
          prop2: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
        })
      })),
      nested_shape_shape: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
        prop3: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,
        prop4: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool
      })
    })
  }),
  array_of_array: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.arrayOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.arrayOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number)),
  children: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,
  identity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,
  updateAspects: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};

/***/ }),

/***/ "./src/internal/test_components/index.js":
/*!***********************************************!*\
  !*** ./src/internal/test_components/index.js ***!
  \***********************************************/
/*! exports provided: TestComponent, DefaultProps, ComponentAsAspect */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _components_TestComponent__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./components/TestComponent */ "./src/internal/test_components/components/TestComponent.jsx");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "TestComponent", function() { return _components_TestComponent__WEBPACK_IMPORTED_MODULE_0__["default"]; });

/* harmony import */ var _components_DefaultProps__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./components/DefaultProps */ "./src/internal/test_components/components/DefaultProps.jsx");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "DefaultProps", function() { return _components_DefaultProps__WEBPACK_IMPORTED_MODULE_1__["default"]; });

/* harmony import */ var _components_ComponentAsAspect__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./components/ComponentAsAspect */ "./src/internal/test_components/components/ComponentAsAspect.jsx");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "ComponentAsAspect", function() { return _components_ComponentAsAspect__WEBPACK_IMPORTED_MODULE_2__["default"]; });






/***/ }),

/***/ 2:
/*!*****************************************************!*\
  !*** multi ./src/internal/test_components/index.js ***!
  \*****************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

module.exports = __webpack_require__(/*! /home/t4rk/projects/experiments/dazzler/src/internal/test_components/index.js */"./src/internal/test_components/index.js");


/***/ }),

/***/ "react":
/*!****************************************************************************************************!*\
  !*** external {"commonjs":"react","commonjs2":"react","amd":"react","umd":"react","root":"React"} ***!
  \****************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports) {

module.exports = __WEBPACK_EXTERNAL_MODULE_react__;

/***/ })

/******/ });
});
//# sourceMappingURL=data:application/json;charset=utf-8;base64, 