"""Autogenerated file: DO NOT EDIT!"""
import typing  # noqa: F401
from dazzler.system import Component, Aspect, UNDEFINED  # noqa: F401


class DatePicker(Component):
    """
    Pick a date from a calendar.

    :CSS:

        ``dazzler-calendar-date-picker``
        - ``picker``
    """
    _aspect_keys = []
    _children = []
    value = Aspect()
    opened = Aspect()
    date_format = Aspect(default='DD MMM YYYY', docstring="(default='DD MMM YYYY')")  # noqa: E501

    def __init__(
            self,
            value: typing.Optional[typing.Union[float, int]] = UNDEFINED,
            opened: typing.Optional[bool] = UNDEFINED,
            date_format: typing.Optional[str] = 'DD MMM YYYY',
            identity: str = None
    ):
        """
        :param value:
        :param opened:
        :param date_format: (default='DD MMM YYYY')
        """
        Component.__init__(self, locals(), identity)
