.dazzler-core-container.btn {
  cursor: pointer;
  user-select: none;
  padding: 0.5rem;
  background-color: #dbdbe0;
  border-radius: 3px;
  border: solid 1px #c9c9ce;
  display: inline-block;
  box-sizing: border-box; }
  .dazzler-core-container.btn:hover {
    background-color: #E5E5EA; }

.dazzler-core-container.scroll {
  overflow: scroll; }

.dazzler-core-container.flex {
  display: flex; }

.dazzler-core-container.row {
  display: flex;
  width: 100%; }
  .dazzler-core-container.row.reverse {
    flex-direction: row-reverse; }

.dazzler-core-container.column {
  display: flex;
  flex-direction: column; }
  .dazzler-core-container.column.reverse {
    flex-direction: column-reverse; }

.dazzler-core-view-port .hidden {
  display: none; }

.dazzler-core-view-port .view-content.bordered {
  border: #c9c9ce solid 1px; }
  .dazzler-core-view-port .view-content.bordered.rounded {
    border-top: none;
    border-radius: 0 0 5px 5px;
    padding: 0.25rem; }

.dazzler-core-view-port .dazzler-tabs {
  display: flex;
  justify-content: space-evenly;
  border-bottom: #c9c9ce solid 1px;
  width: 100%; }
  .dazzler-core-view-port .dazzler-tabs.vertical {
    flex-direction: column;
    border-bottom: None; }
    .dazzler-core-view-port .dazzler-tabs.vertical .dazzler-tab {
      border-right: None;
      border-bottom: #c9c9ce solid 1px; }
  .dazzler-core-view-port .dazzler-tabs.rounded {
    border-bottom: none;
    justify-content: initial; }
  .dazzler-core-view-port .dazzler-tabs .filler {
    flex-grow: 1;
    border-bottom: #c9c9ce solid 1px; }
  .dazzler-core-view-port .dazzler-tabs .dazzler-tab {
    border-right: #c9c9ce solid 1px;
    flex-grow: 1;
    cursor: pointer;
    user-select: none;
    padding: 0.5rem;
    text-align: center; }
    .dazzler-core-view-port .dazzler-tabs .dazzler-tab.tab-active {
      background-color: #5294e2;
      color: white; }
      .dazzler-core-view-port .dazzler-tabs .dazzler-tab.tab-active:hover {
        background-color: #52a3f1; }
    .dazzler-core-view-port .dazzler-tabs .dazzler-tab:hover {
      background-color: #E5E5EA; }
    .dazzler-core-view-port .dazzler-tabs .dazzler-tab:last-child {
      border-right: none; }
    .dazzler-core-view-port .dazzler-tabs .dazzler-tab.rounded {
      flex-grow: unset;
      min-width: 10rem;
      border: #c9c9ce solid 1px;
      background-color: #dbdbe0;
      border-radius: 5px 5px 0 0; }
      .dazzler-core-view-port .dazzler-tabs .dazzler-tab.rounded:hover {
        background-color: #E5E5EA; }
      .dazzler-core-view-port .dazzler-tabs .dazzler-tab.rounded.tab-active {
        background-color: initial;
        color: initial;
        border-bottom: none; }
        .dazzler-core-view-port .dazzler-tabs .dazzler-tab.rounded.tab-active.hover {
          background-color: initial; }

.dazzler-core-progress-bar {
  width: 100%;
  height: 2rem;
  background-color: #F1F1F1; }
  .dazzler-core-progress-bar.rounded {
    border-radius: 8px; }
  .dazzler-core-progress-bar .progress {
    background-color: #5294e2;
    color: #ffffff;
    height: 100%;
    display: flex;
    justify-content: center;
    align-items: center; }
    .dazzler-core-progress-bar .progress.striped {
      background: repeating-linear-gradient(45deg, #5294e2, #5294e2 1rem, #52a3f1 1rem, #52a3f1 2rem); }
    .dazzler-core-progress-bar .progress.rounded {
      border-radius: 8px; }
    .dazzler-core-progress-bar .progress.low {
      background-color: #D9534F; }
      .dazzler-core-progress-bar .progress.low.striped {
        background: repeating-linear-gradient(45deg, #D9534F, #D9534F 1rem, #DE6C69 1rem, #DE6C69 2rem); }
    .dazzler-core-progress-bar .progress.high {
      background-color: #F0AD4E; }
      .dazzler-core-progress-bar .progress.high.striped {
        background: repeating-linear-gradient(45deg, #F0AD4E, #F0AD4E 1rem, #F2B968 1rem, #F2B968 2rem); }
    .dazzler-core-progress-bar .progress.optimum {
      background-color: #5CB85C; }
      .dazzler-core-progress-bar .progress.optimum.striped {
        background: repeating-linear-gradient(45deg, #5CB85C, #5CB85C 1rem, #74c274 1rem, #74c274 2rem); }

.dazzler-core-button {
  border-style: solid;
  border-width: 0;
  cursor: pointer;
  color: white;
  padding: 0.25rem;
  margin: 0.1325rem; }
  .dazzler-core-button:focus {
    outline: none; }
  .dazzler-core-button.bordered {
    border-width: 1px; }
  .dazzler-core-button.default {
    background-color: #dbdbe0;
    color: #606060; }
    .dazzler-core-button.default.bordered {
      border-color: #c9c9ce; }
    .dazzler-core-button.default:hover, .dazzler-core-button.default:focus {
      background-color: #E5E5EA; }
  .dazzler-core-button.rounded {
    border-radius: 5px; }
  .dazzler-core-button.circle {
    border-radius: 50%; }
  .dazzler-core-button.primary {
    color: white; }
    .dazzler-core-button.primary.bordered {
      border-color: #107bdb; }
    .dazzler-core-button.primary:hover, .dazzler-core-button.primary:focus {
      background-color: #52a3f1; }
  .dazzler-core-button.danger.bordered {
    border-color: #ac4c49; }
  .dazzler-core-button.danger:hover, .dazzler-core-button.danger:focus {
    background-color: #DE6C69; }
  .dazzler-core-button.warning.bordered {
    border-color: #de9c4d; }
  .dazzler-core-button.warning:hover, .dazzler-core-button.warning:focus {
    background-color: #F2B968; }
  .dazzler-core-button.success.bordered {
    border-color: #4a944a; }
  .dazzler-core-button.success:hover, .dazzler-core-button.success:focus {
    background-color: #74c274; }
  .dazzler-core-button.tiny {
    padding: 0;
    font-size: smaller; }
  .dazzler-core-button.small {
    padding: 0.125rem;
    font-size: small; }
  .dazzler-core-button.medium {
    font-size: medium;
    border-width: 0.125rem; }
  .dazzler-core-button.large {
    padding: 0.5rem;
    font-size: large;
    border-width: 0.25rem; }
  .dazzler-core-button.larger {
    padding: 0.75rem;
    font-size: larger;
    border-width: 0.33rem; }
  .dazzler-core-button.x-large {
    padding: 1rem;
    font-size: x-large;
    border-width: 0.44rem; }
  .dazzler-core-button.xx-large {
    padding: 1.25rem;
    font-size: xx-large;
    border-width: 0.5rem; }

.dazzler-core-slider {
  height: 1rem;
  display: flex;
  -moz-user-select: none; }
  .dazzler-core-slider .slider-handle {
    height: 1rem;
    width: 0.8rem;
    background-color: #dbdbe0;
    border: #c9c9ce solid 1px;
    border-radius: 3px;
    cursor: pointer; }
    .dazzler-core-slider .slider-handle.dragged {
      background-color: #c9c9ce;
      -moz-user-select: none; }
  .dazzler-core-slider .slider-area {
    height: 0.75rem;
    flex-grow: 1;
    border: #E5E5EA solid 1px;
    border-radius: 3px;
    display: flex;
    align-items: center; }
  .dazzler-core-slider .slider-spacer {
    height: 0.75rem;
    background-color: #dbdbe0;
    border: #c9c9ce solid 1px;
    border-right: none; }

.dazzler-core-modal .modal-content {
  background-color: #dbdbe0;
  border: #E5E5EA 0.125rem solid;
  border-radius: 5px;
  opacity: 100%;
  width: calc(60%);
  margin-top: 2rem;
  margin-right: auto;
  margin-left: auto; }
  @media only screen and (max-width: 600px) {
    .dazzler-core-modal .modal-content {
      width: calc(90%); } }
  @media only screen and (max-width: 1000px) {
    .dazzler-core-modal .modal-content {
      width: calc(80%); } }

.dazzler-core-modal .modal-overlay {
  display: none;
  z-index: 1000; }
  .dazzler-core-modal .modal-overlay.modal-active {
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    display: block;
    background-color: #101013;
    opacity: 0.8; }

.dazzler-core-modal .modal-header {
  border-bottom: #c9c9ce 0.125rem solid;
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 0.5rem; }
  .dazzler-core-modal .modal-header .modal-closer {
    background-color: #c9c9ce;
    border: #E5E5EA;
    border-radius: 5px;
    width: 2rem;
    height: 2rem;
    cursor: pointer;
    user-select: none;
    display: flex;
    justify-content: center;
    align-items: center;
    align-self: flex-start;
    font-weight: bolder; }
    .dazzler-core-modal .modal-header .modal-closer:hover, .dazzler-core-modal .modal-header .modal-closer:focus {
      background-color: #E5E5EA; }

.dazzler-core-modal .modal-body {
  padding: 0.5rem; }

.dazzler-core-modal .modal-footer {
  border-top: #c9c9ce 0.125rem solid;
  padding: 0.5rem; }

.dazzler-core-grid {
  display: flex;
  flex-direction: column;
  align-items: baseline; }
  .dazzler-core-grid .grid-row {
    display: flex;
    width: 100%;
    justify-content: space-between; }

.dazzler-core-form .form-error {
  color: #D9534F; }

.dazzler-core-text-area.autosize {
  overflow: hidden;
  resize: none; }

.dazzler-core-list-box.vertical.scrollable {
  overflow-y: auto; }

.dazzler-core-list-box.horizontal {
  display: flex; }
  .dazzler-core-list-box.horizontal.scrollable {
    overflow-x: auto; }

.dazzler-core-dropdown {
  position: relative; }
  .dazzler-core-dropdown .drop-toggle {
    cursor: pointer;
    border: solid 1px #c9c9ce;
    border-radius: 3px;
    user-select: none;
    display: flex;
    justify-content: space-between;
    width: 100%; }
    .dazzler-core-dropdown .drop-toggle > div:first-child {
      flex-grow: 1; }
    .dazzler-core-dropdown .drop-toggle .drop-symbol {
      justify-self: flex-end;
      padding: 0.5rem; }
  .dazzler-core-dropdown .drop-container {
    display: none;
    border: solid 1px #c9c9ce;
    border-top: none;
    border-radius: 3px;
    position: absolute;
    z-index: 100;
    background-color: #fff; }
    .dazzler-core-dropdown .drop-container.opened {
      display: block; }
    .dazzler-core-dropdown .drop-container.scrollable {
      overflow-y: auto; }
  .dazzler-core-dropdown .dropdown-item {
    padding: 0.5rem;
    cursor: pointer; }
    .dazzler-core-dropdown .dropdown-item:hover, .dazzler-core-dropdown .dropdown-item:focus {
      background-color: #c9c9ce; }
      .dazzler-core-dropdown .dropdown-item:hover.selected, .dazzler-core-dropdown .dropdown-item:focus.selected {
        background-color: initial; }
    .dazzler-core-dropdown .dropdown-item.selected {
      width: 100%; }
  .dazzler-core-dropdown .selected-items {
    display: flex;
    flex-wrap: wrap; }
    .dazzler-core-dropdown .selected-items .drop-selected-item {
      display: flex;
      align-items: center;
      background-color: #E5E5EA;
      border: 1px solid #c9c9ce;
      border-radius: 3px;
      margin: 0.125rem; }
      .dazzler-core-dropdown .selected-items .drop-selected-item .selected-label {
        margin-left: 0.25rem; }
      .dazzler-core-dropdown .selected-items .drop-selected-item .selected-remover {
        display: flex;
        align-items: center;
        margin-left: 0.25rem;
        border-radius: 0 3px 3px 0;
        padding-left: 0.25rem;
        padding-right: 0.25rem;
        height: 100%; }
        .dazzler-core-dropdown .selected-items .drop-selected-item .selected-remover:hover, .dazzler-core-dropdown .selected-items .drop-selected-item .selected-remover:focus {
          background-color: #c9c9ce; }
  .dazzler-core-dropdown .no-results {
    padding: 0.5rem;
    text-align: center;
    user-select: none; }
  .dazzler-core-dropdown .search-content {
    height: 0;
    visibility: hidden;
    position: absolute;
    top: 0; }
  .dazzler-core-dropdown .dropdown-search-input {
    border: none;
    margin: 2px 4px; }
  .dazzler-core-dropdown .drop-controls {
    display: flex;
    flex-wrap: wrap; }


/*# sourceMappingURL=dazzler_core_6ee7514ee44449b3f910.js.map*/