"""
Component packages of dazzler.

- ``core``: Lightweight interactive components.
- ``extra``: More components that may not be needed by all pages.
- ``markdown``: Markdown and CodeBlock.
- ``calendar``: Date & time related components.
"""
