"""Autogenerated file: DO NOT EDIT!"""
import typing  # noqa: F401
from dazzler.system import Component, Aspect, UNDEFINED  # noqa: F401


class Input(Component):
    """
    Html input wrapper.
    """
    _aspect_keys = []
    _children = []
    id = Aspect()
    class_name = Aspect()
    style = Aspect()
    name = Aspect()
    required = Aspect()
    value = Aspect(default='', docstring="(default='')")
    type = Aspect(docstring="(Possible values: 'hidden', 'text', 'number', 'search', 'tel', 'password', 'range', 'email', 'url', 'submit', 'checkbox', 'reset')")  # noqa: E501
    placeholder = Aspect()
    pattern = Aspect()
    auto_complete = Aspect()
    auto_focus = Aspect()
    auto_save = Aspect()
    auto_correct = Aspect()
    disabled = Aspect()
    n_blur = Aspect(default=0, docstring="(default=0)")
    n_submit = Aspect(default=0, docstring="(default=0)")
    min = Aspect()
    min_length = Aspect()
    max_length = Aspect()
    max = Aspect()
    step = Aspect()
    multiple = Aspect()
    checked = Aspect(default=False, docstring="(default=False)")

    def __init__(
            self,
            id: typing.Optional[str] = UNDEFINED,
            class_name: typing.Optional[str] = UNDEFINED,
            style: typing.Optional[typing.Dict] = UNDEFINED,
            name: typing.Optional[str] = UNDEFINED,
            required: typing.Optional[bool] = UNDEFINED,
            value: typing.Optional[typing.Union[str, typing.Union[float, int]]] = '',  # noqa: E501
            type: typing.Optional[typing.Any] = UNDEFINED,
            placeholder: typing.Optional[str] = UNDEFINED,
            pattern: typing.Optional[str] = UNDEFINED,
            auto_complete: typing.Optional[str] = UNDEFINED,
            auto_focus: typing.Optional[bool] = UNDEFINED,
            auto_save: typing.Optional[str] = UNDEFINED,
            auto_correct: typing.Optional[str] = UNDEFINED,
            disabled: typing.Optional[bool] = UNDEFINED,
            n_blur: typing.Optional[typing.Union[float, int]] = 0,
            n_submit: typing.Optional[typing.Union[float, int]] = 0,
            min: typing.Optional[typing.Union[float, int]] = UNDEFINED,
            min_length: typing.Optional[typing.Union[float, int]] = UNDEFINED,
            max_length: typing.Optional[typing.Union[float, int]] = UNDEFINED,
            max: typing.Optional[typing.Union[float, int]] = UNDEFINED,
            step: typing.Optional[typing.Union[str, typing.Union[float, int]]] = UNDEFINED,  # noqa: E501
            multiple: typing.Optional[bool] = UNDEFINED,
            checked: typing.Optional[bool] = False,
            identity: str = None
    ):
        """
        :param id:
        :param class_name:
        :param style:
        :param name:
        :param required:
        :param value: (default='')
        :param type: (Possible values: 'hidden', 'text', 'number',
            'search', 'tel', 'password', 'range', 'email', 'url', 'submit',
            'checkbox', 'reset')
        :param placeholder:
        :param pattern:
        :param auto_complete:
        :param auto_focus:
        :param auto_save:
        :param auto_correct:
        :param disabled:
        :param n_blur: (default=0)
        :param n_submit: (default=0)
        :param min:
        :param min_length:
        :param max_length:
        :param max:
        :param step:
        :param multiple:
        :param checked: (default=False)
        """
        Component.__init__(self, locals(), identity)
